mangadap.spectra.rowstackedspectra module
=========================================

.. automodule:: mangadap.spectra.rowstackedspectra
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
